@@ -970,7 +970,7 @@ c     | in span(A) orthogonal to U(:,1:j), so we can   |
 c     | continue the LBD and "deflate" the subspace by |
 c     | setting beta_{j+1} = 0.                        |
 c     %------------------------------------------------%
-               call dsafescal(n,beta,U(1,j+1))
+               call dsafescal(m,beta,U(1,j+1))
                beta = zero
                force_reorth = .true.
                if (delta .gt. zero) then
